@@ -21,12 +21,10 @@ public:
     virtual ~NZFiles();
 	virtual QUrl getUrl();
 	void initSettings();
-	virtual void updateSettingsFile();
-	virtual void checkDataStatus();
 	virtual void setInput(DownloadInput d);
 	virtual QString finishedDownload(QString channel, QIODevice *source);
-	virtual QStringList getChannelList();
 	void sendRecordMsg(QStringList data);
+	virtual bool isSingleXMLTVFile() { return false; }
 
 signals:
 
@@ -37,14 +35,9 @@ private slots:
 
 protected:
 	void updateDownloadIndexes();
-	void prepareUrl();
 
 private:
 	const char* HELPERPATH;
-
-	// NZ channels names are different from the channel code we need during a network download request url
-	// hence we maintain this mapping as the codes dont mean much to the user while displaying the list :)
-	QMap<QString , QString> _channelCodeMap;
 };
 
 #endif // NZFILES_H
