@@ -13,12 +13,13 @@ class QWidget;
 class MyToolButton : public QToolButton
 {
 public:
-	MyToolButton(QIcon icon, QString text, QMainWindow *parent) : QToolButton(parent)
+	MyToolButton(QIcon icon, QString text, QMainWindow* parent) : QToolButton(parent)
 	{
 		setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
 		setIcon(icon);
 		setText(text);
 		setAutoRaise(true);
+		setIconSize(QSize(150, 150));
 	}
 
 	~MyToolButton() { };
@@ -36,7 +37,7 @@ public:
 	QStringList getRegionList()
 	{
 		QStringList list;
-		list << "UK" << "AU" << "NZ" << "SE" << "DE" << "ES" << "IT" << "HR" << "SI";
+		list << "UK" << "AU" << "NZ" << "SE" << "DE" << "FR" << "ES" << "IT" << "HR" << "SI" << "DK" << "NL" << "BE" << "NO" << "RU" << "MY" << "ZA" << "PL" << "FI";
 		return list;
 	}
 
@@ -48,10 +49,20 @@ private slots:
 	void setNZ();
 	void setSE();
 	void setDE();
+	void setFR();
 	void setES();
 	void setIT();
 	void setHR();
 	void setSI();
+	void setDK();
+	void setNL();
+	void setBE();
+	void setNO();
+	void setRU();
+	void setMY();
+	void setZA();
+	void setPL();
+	void setFI();
 	void setRegion(QString region);
 
 signals:
