@@ -5,6 +5,7 @@
 #include <QStringList>
 #include <QSet>
 #include <QUrl>
+#include <QMap>
 #include <QProcess>
 
 class QIODevice;
@@ -20,11 +21,8 @@ public:
     virtual ~UKFiles();
 	virtual QUrl getUrl();
 	void initSettings();
-	virtual void updateSettingsFile();
-	virtual void checkDataStatus();
 	virtual void setInput(DownloadInput d);
 	virtual QString finishedDownload(QString channel, QIODevice *source);
-	virtual QStringList getChannelList();
 	void sendRecordMsg(QStringList data);
 
 signals:
@@ -36,10 +34,8 @@ private slots:
 
 protected:
 	void updateDownloadIndexes();
-	void prepareUrl();
 
 private:
-	QProcess *_processPtr;
 	const char* HELPERPATH;
 };
 
